@@ -5,12 +5,18 @@ import tempfile
 import time
 
 import mmcv
+import numpy as np
 import torch
 import torch.distributed as dist
+from mmcv.image import tensor2imgs
 from mmcv.runner import get_dist_info
 
 
-def single_gpu_test(model, data_loader, show=False, out_dir=None):
+def single_gpu_test(model,
+                    data_loader,
+                    show=False,
+                    out_dir=None,
+                    **show_kwargs):
     model.eval()
     results = []
     dataset = data_loader.dataset
@@ -18,10 +24,43 @@ def single_gpu_test(model, data_loader, show=False, out_dir=None):
     for i, data in enumerate(data_loader):
         with torch.no_grad():
             result = model(return_loss=False, **data)
-        results.append(result)
+
+        batch_size = len(result)
+        results.extend(result)
 
         if show or out_dir:
-            pass  # TODO
+            scores = np.vstack(result)
+            pred_score = np.max(scores, axis=1)
+            pred_label = np.argmax(scores, axis=1)
+            pred_class = [model.CLASSES[lb] for lb in pred_label]
+
+            img_metas = data['img_metas'].data[0]
+            imgs = tensor2imgs(data['img'], **img_metas[0]['img_norm_cfg'])
+            assert len(imgs) == len(img_metas)
+
+            for i, (img, img_meta) in enumerate(zip(imgs, img_metas)):
+                h, w, _ = img_meta['img_shape']
+                img_show = img[:h, :w, :]
+
+                ori_h, ori_w = img_meta['ori_shape'][:-1]
+                img_show = mmcv.imresize(img_show, (ori_w, ori_h))
+
+                if out_dir:
+                    out_file = osp.join(out_dir, img_meta['ori_filename'])
+                else:
+                    out_file = None
+
+                result_show = {
+                    'pred_score': pred_score[i],
+                    'pred_label': pred_label[i],
+                    'pred_class': pred_class[i]
+                }
+                model.module.show_result(
+                    img_show,
+                    result_show,
+                    show=show,
+                    out_file=out_file,
+                    **show_kwargs)
 
         batch_size = data['img'].size(0)
         for _ in range(batch_size):
